@@ -16,7 +16,6 @@ from .const import (
     DDP_PORTS,
     Quality,
     Resolution,
-    StreamType,
     FPS,
 )
 from .ddp import async_get_status, get_status, wakeup
@@ -37,7 +36,7 @@ class RPDevice:
 
     Most, if not all user interactions should be performed with this class.
     Status must be polled manually with `get_status`.
-    Most iteractions cannot be used unless there is a valid status.
+    Most interactions cannot be used unless there is a valid status.
 
     :param host: IP address of Remote Play Host
     """
@@ -162,13 +161,13 @@ class RPDevice:
         user: str,
         profiles: dict = None,
         profile_path="",
-        receiver: AVReceiver = None,
         loop: asyncio.AbstractEventLoop = None,
+        receiver: AVReceiver = None,
         resolution: Union[Resolution, str, int] = "360p",
         fps: Union[FPS, str, int] = "low",
         quality: Union[Quality, str, int] = "very_low",
-        codec: Union[StreamType, str, int] = "h264",
-        **kwargs,
+        codec: str = "h264",
+        hdr: bool = False,
     ) -> Union[Session, None]:
         """Return initialized session if session created else return None.
         Also connects a controller.
@@ -190,13 +189,13 @@ class RPDevice:
         self._session = Session(
             self.host,
             profile,
-            receiver,
-            loop,
-            resolution,
-            fps,
-            quality,
-            codec,
-            **kwargs,
+            loop=loop,
+            receiver=receiver,
+            resolution=resolution,
+            fps=fps,
+            quality=quality,
+            codec=codec,
+            hdr=hdr,
         )
         self.controller = Controller(self.session)
         return self._session
@@ -240,7 +239,7 @@ class RPDevice:
                 _LOGGER.error("Error connecting")
                 return False
             try:
-                await asyncio.wait_for(self.session.stream_ready.wait(), 5)
+                await asyncio.wait_for(self.session.stream_ready_event.wait(), 5)
             except asyncio.TimeoutError:
                 _LOGGER.error("Timed out waiting for stream to start")
                 return False
